pub fn get_shell(show_path: bool, show_version: bool) -> Option<String>Expand description
Get the current shell name and version.
If show_path is true, the full path to the shell executable will be included.
If show_version is true, the version of the shell will be included.
Returns None if the SHELL environment variable is not set.