Given a distro name, returns a string of its corresponding ASCII art.
If the distro isn’t found, an empty string is returned.
If the distro is “off”, an empty string is returned.
Given a slice of color indices or a distro name, generates a HashMap
of cX keys (where X is the index, starting from 1) mapped to the
corresponding ANSI foreground color codes.
Given a string of comma-separated color indices or a distro name, returns a
HashMap of color codes c0 to cX as found in the given distro’s color
definition. The color codes are from the ANSI color palette.
Given a distro name, returns a HashMap of color codes c0 to cX as found
in the given distro’s color definition. The color codes are from the
ANSI color palette. If the distro isn’t found, an empty HashMap is returned.
Generates a vector of 2 strings, each containing a row of 8 blocks
colored with different ANSI foreground colors. The first string has
normal colors, the second has bold colors.