Re-exports
pub use system_info::SystemInfo;pub use system_info::PROTOCOL_VERSION;
Modules
Functions
- clear_
system_ info_ cache - Clears the system info cache. Useful for testing or when fresh data is needed.
- gather_
system_ info - Collects system information using the provided configuration and returns the stable JSON model. Results are cached for 5 seconds to avoid redundant computation on quick successive calls.