Skip to main contentModule enums
Source - SongInfo
- Holds information about the currently playing song, if available.
Used for the media/song block in the output.
- BatteryDisplayMode
- Controls how battery information is displayed.
- DiskDisplay
- Controls the format of the disk usage display.
- DiskSubtitle
- Controls the subtitle/label shown for each disk in the disk usage output.
- DistroDisplay
- Controls the format of the distribution (distro) string in the output.
Used to customize how much detail about the OS is shown.
- MemoryUnit
- Controls the unit used to display memory usage.
- OsAgeShorthand
- Controls the format of the OS age string in the output.
- PackageShorthand
- Controls how the package manager summary is displayed in the output.
- UptimeShorthand
- Controls the format of the uptime string in the output.